package com.izouma.awesomeadmin.dao;

import java.util.*;
import com.izouma.awesomeadmin.datasource.DataSource;
import org.springframework.stereotype.Repository;
import com.izouma.awesomeadmin.model.Testaaaone;


/**
*  Dao接口
*/
@Repository("com.zoumaframe.dao.TestaaaoneMapper")
public interface TestaaaoneMapper{

    int deleteByPrimaryKey(Integer id);

    int insertSelective(Testaaaone record);

    Testaaaone selectByPrimaryKey(Integer id);

    int updateByPrimaryKeySelective(Testaaaone record);

    List<Testaaaone> queryAllTestaaaone(Testaaaone record);

    List<Testaaaone> queryTestaaaoneByPage(Map<String, Object> parameter);

    int delete(String id);

    Testaaaone queryTestaaaone(Testaaaone record);

    List<Testaaaone> query(Testaaaone record);
}

