package com.izouma.awesomeadmin.service.impl;

import java.util.*;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.izouma.awesomeadmin.constant.AppConstant;
import com.izouma.awesomeadmin.dto.Page;
import com.izouma.awesomeadmin.model.Testaaaone;
import com.izouma.awesomeadmin.service.TestaaaoneService;
import com.izouma.awesomeadmin.dao.TestaaaoneMapper;

/**
*  service接口实现类
*/
@Service
public class TestaaaoneServiceImpl implements TestaaaoneService{

    private static Logger logger = Logger.getLogger(TestaaaoneServiceImpl.class);

    @Autowired
    private TestaaaoneMapper testaaaoneMapper;

    @Override
    public List<Testaaaone> getTestaaaoneList(Testaaaone record) {

        logger.info("getTestaaaoneList");
        try {

        return testaaaoneMapper.queryAllTestaaaone(record);
        } catch (Exception e) {
        logger.error("getTestaaaoneList", e);
        }

        return null;
    }
    @Override
    public List<Testaaaone> getTestaaaoneByPage(Page page, Testaaaone record) {

        logger.info("getTestaaaoneByPage");
        try {

        Map<String, Object> parameter = new HashMap<String, Object>();
        parameter.put("record", record);
        parameter.put(AppConstant.PAGE, page);

        return testaaaoneMapper.queryTestaaaoneByPage(parameter);
        } catch (Exception e) {
        logger.error("getTestaaaoneByPage", e);
        }

        return null;
    }

    @Override
    public Testaaaone getTestaaaoneById(String id) {

        logger.info("getTestaaaoneyId");
        try {

            return testaaaoneMapper.selectByPrimaryKey(Integer.valueOf(id));
        } catch (Exception e) {
        logger.error("getTestaaaoneById", e);
        }

        return null;
    }

    @Override
    public Testaaaone getTestaaaone(Testaaaone record) {

        logger.info("getTestaaaone");
        try {

            return testaaaoneMapper.queryTestaaaone(record);
        } catch (Exception e) {
        logger.error("getTestaaaone", e);
        }

        return null;
    }

    @Override
    public boolean createTestaaaone(Testaaaone record) {

        logger.info("createTestaaaone");
        try {

            int updates = testaaaoneMapper.insertSelective(record);

            if (updates > 0) {
                 return true;
            }
        } catch (Exception e) {
            logger.error("createTestaaaone", e);
        }

        return false;
    }

    @Override
    public boolean deleteTestaaaone(String id) {

        logger.info("deleteTestaaaone");
        try {

             int updates = testaaaoneMapper.delete(id);

            if (updates > 0) {
                 return true;
            }
        } catch (Exception e) {
             logger.error("deleteTestaaaone", e);
        }

        return false;
    }

    @Override
    public boolean updateTestaaaone(Testaaaone record) {

        logger.info("updateTestaaaone");
        try {

            int updates = testaaaoneMapper.updateByPrimaryKeySelective(record);

            if (updates > 0) {
                 return true;
            }
        } catch (Exception e) {
             logger.error("updateTestaaaone", e);
        }

        return false;
    }
}

